Documentation
¶
Index ¶
- type Config
- type Provider
- func (p *Provider) BeginAuth(state string) (goth.Session, error)
- func (p *Provider) Client() *http.Client
- func (p *Provider) Debug(debug bool)
- func (p *Provider) DefaultGenerateVerificationToken() (string, error)
- func (p *Provider) DefaultNormalizeIdentifier(identifier string) string
- func (p *Provider) DefaultSendVerificationRequest(params VerificationRequestParams) error
- func (p *Provider) FetchUser(session goth.Session) (goth.User, error)
- func (p *Provider) Name() string
- func (p *Provider) RefreshToken(refreshToken string) (*oauth2.Token, error)
- func (p *Provider) RefreshTokenAvailable() bool
- func (p *Provider) SendVerificationRequest(email, callbackURL string) error
- func (p *Provider) SetName(name string)
- func (p *Provider) UnmarshalSession(data string) (goth.Session, error)
- type SMTPServer
- type Session
- type VerificationRequestParams
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Server SMTPServer
From string
MaxAge time.Duration
SendVerificationRequest func(params VerificationRequestParams) error
GenerateVerificationToken func() (string, error)
NormalizeIdentifier func(identifier string) string
}
type Provider ¶
type Provider struct {
ClientKey string
Secret string
CallbackURL string
HTTPClient *http.Client
// contains filtered or unexported fields
}
Provider is the implementation of `goth.Provider` for email authentication.
func (*Provider) DefaultGenerateVerificationToken ¶
func (*Provider) DefaultNormalizeIdentifier ¶
func (*Provider) DefaultSendVerificationRequest ¶
func (p *Provider) DefaultSendVerificationRequest(params VerificationRequestParams) error
func (*Provider) RefreshToken ¶
func (*Provider) RefreshTokenAvailable ¶
func (*Provider) SendVerificationRequest ¶
type Session ¶
Session stores data during the auth process with Email.
func (*Session) Authorize ¶
Authorize the session with Email and return the email address to be stored for future use.
func (Session) GetAuthURL ¶
GetAuthURL will return the URL set by calling the `BeginAuth` function on the Email provider.
Click to show internal directories.
Click to hide internal directories.